#!/bin/bash
#
#   USAGE:  buildSqlite.sh <product_directory> [tar]
#   NOTE:  we build sqlite with the native compiler

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"

}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=sqlite
origpkgver=v3_26_00_00
pkgver=${origpkgver}
ssibuildshims_version=v1_04_13
##pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgbasever=`echo ${origpkgver} | sed -e 's/_//g' | sed -e 's/^v//'`
pkgtarname=${package}-autoconf-${pkgbasever}

get_this_dir

get_ssibuildshims

source define_basics NO_QUAL

conftar="${patchdir}/sqlite3_ups_${pkgbasever}.tar.bz2"

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

set -x

cd ${sourcedir}
tar xf ${tardir}/${pkgtarname}.tar.gz || ssi_die "ERROR: untar source failed."
tar xf ${conftar} || ssi_die "ERROR: untar configuration patch failed."

cd ${blddir}

CFLAGS="-O3 -g -DNDEBUG -fno-omit-frame-pointer" \
 CPPFLAGS="-DSQLITE_ENABLE_FTS3 -DSQLITE_ENABLE_FTS3_PARENTHESIS -DSQLITE_ENABLE_RTREE -DSQLITE_ENABLE_COLUMN_METADATA" \
 ${sourcedir}/${pkgtarname}/configure --prefix=${pkgdir}

make -j ${ncore} || ssi_die "ERROR: make failed."
make check || ssi_die "ERROR: make check failed."
make install || ssi_die "ERROR: make install failed."

set +x


if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# Remove .la files.
find ${pkgdir} -name '*.la' | xargs rm -vf

# declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL || \
ssi_die "Unable to declare product to UPS."


# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}
echo "${package} is installed at ${SQLITE_FQ_DIR}"

# this must be last 
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0

